﻿Imports System.Data.Linq
Imports WebShopping
Imports System.Transactions

<HandleError()> _
Public Class AccountController
    Inherits System.Web.Mvc.Controller

    Public Function LogOn() As ActionResult
        Session("RegisterData") = Nothing

        Return View()
    End Function

    <HttpPost()> _
    Public Function LogOn(ByVal collection As FormCollection) As ActionResult
        Dim encryptPassword As String = Crypt.EncryptSHA256(collection.Item("password"))

        collection.Item("user_id") = collection.Item("user_id").Trim

        ' バリデーション
        If collection.Item("user_id") = "" Then
            ModelState.AddModelError("", "ユーザIDを入力してください")
        End If

        If collection.Item("password") = "" Then
            ModelState.AddModelError("", "パスワードを入力してください")
        End If

        ' バリデーションエラーが発生したとき
        If Not ModelState.IsValid Then
            Return View()
        End If

        Dim connStr As String = Util.GetConnectionString
        Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

        Dim Auth As Boolean = False
        Dim Lock As Boolean = False
        Dim Deleted As Boolean = False
        Try
            ' ロックされているか判定する
            dc.checkUserLock(Lock, collection.Item("user_id"))

            ' ロックされているときメッセージを表示する
            If Lock = True Then
                ModelState.AddModelError("", "ユーザ" & collection.Item("user_id") & ")はロックされています。管理者までご連絡ください")

                If Not ModelState.IsValid Then
                    Return View()
                End If
            End If

            ' 無効化されているか判定する
            dc.checkUserDeleted(Deleted, collection.Item("user_id"))

            ' 無効化されているとき
            If Deleted = True Then
                ModelState.AddModelError("", "ユーザ(" & collection.Item("user_id") & ")は無効化されています。管理者までご連絡ください")

                If Not ModelState.IsValid Then
                    Return View()
                End If
            End If

            ' パスワードがあっているか判定する
            dc.checkUserPassword(Auth, collection.Item("user_id"), encryptPassword)

            If Auth = True Then ' パスワードが正しい
                ' データベースから情報を読み込む
                Dim user = (From u In dc.GetTable(Of MstUser)() Where u.USER_ID = collection.Item("user_id")).First


                ' アカウント情報を初期化する
                Dim acc As AccountInfo = New AccountInfo
                acc.USER_ID = user.USER_ID
                acc.USER_NAME = user.KANJI_SEI & user.KANJI_MEI
                acc.LAST_LOGIN_DATE = user.LAST_LOGIN_DATE
                acc.LAST_LOGIN_DATE2 = user.LAST_LOGIN_DATE2
                acc.LAST_PASSWORD_CHANGE = DateTime.Parse(user.LAST_PASSWORD_CHANGE)


                Session.Clear()

                Session("AccountInfo") = acc

                ' データベースに書き込む
                ' 1)最終ログイン日時
                ' 2)ログイン失敗カウントの初期化
                ' 3)ログインログ
                Using ts = New TransactionScope
                    dc.updateUserLastLoginDate(collection.Item("user_id"))
                    dc.resetUserFailedCount(collection.Item("user_id"))
                    dc.insertUserLoginLog(collection.Item("user_id"), True, System.Web.HttpContext.Current.Request.UserHostAddress, Session.SessionID)
                    dc.SubmitChanges()
                    ts.Complete()

                End Using
                Return RedirectToAction("Index", "Home")
            Else ' パスワードが間違っている
                Using ts = New TransactionScope

                    ' ユーザ情報の取得
                    Dim user = (From u In dc.GetTable(Of MstUser)() Where u.USER_ID = collection.Item("user_id")).FirstOrDefault

                    ' ユーザが存在するとき
                    If Not user Is Nothing Then
                        ' ログイン失敗カウントをインクリメント
                        dc.incrementUserFailedCount(collection.Item("user_id"))

                        ' ログイン失敗カウントが一定数以上だったらユーザをロックする
                        If user.FAILED_COUNT >= (CInt(Util.GetAppSetting("PasswordFailedCount")) - 1) Then
                            dc.updateUserLock(collection.Item("user_id"), True)
                        End If


                    End If
                    ' ログインログを書き込む
                    dc.insertUserLoginLog(collection.Item("user_id"), False, System.Web.HttpContext.Current.Request.UserHostAddress, Session.SessionID)


                    dc.SubmitChanges()
                    ts.Complete()
                End Using

                ' ログインに失敗したことを表示
                ModelState.AddModelError("", "ログインに失敗しました")

                Return View()
            End If
        Catch ex As Exception
            Return RedirectToAction("Maintenance", "Home")
        End Try
    End Function

    Public Function LogOff() As ActionResult
        Session.Clear()
        Return RedirectToAction("Index", "Home")
    End Function

    Public Function PasswordChange() As ActionResult
        Dim data As PasswordChangeData = TryCast(Session("PasswordChangeData"), PasswordChangeData)

        If Not data Is Nothing Then
            ViewData("user_id_value") = data.OPERATOR_ID
        End If

        Return View()
    End Function

    <HttpPost()> _
    Public Function PasswordChange(ByVal collection As FormCollection) As ActionResult
        Dim connStr As String = Util.GetConnectionString
        Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

        If collection("button") = "確認" Then ' 確認ボタンを押したとき
            ' Trim
            collection("user_id") = collection("user_id").Trim
            ' 再表示用に設定
            ViewData("user_id_value") = collection("user_id")

            ' バリデーション
            ' オペレータID
            If collection("user_id") = "" Then
                ModelState.AddModelError("", "ユーザIDは必須項目です")
            Else
                If collection("old_password") = "" Then
                    ModelState.AddModelError("", "旧パスワードは必須項目です")
                Else
                    Dim encryptPassword As String = Crypt.EncryptSHA256(collection.Item("old_password"))
                    Dim pw = From t In dc.GetTable(Of MstUser)() Where t.USER_ID = collection("user_id") AndAlso t.ENCRYPTED_PASSWORD = encryptPassword

                    If pw.Count = 0 Then
                        ModelState.AddModelError("", "ユーザIDまたは旧パスワードが間違っています")
                    End If
                End If

            End If
            ' パスワード
            If collection("new_password") = "" Then
                ModelState.AddModelError("", "新パスワードは必須項目です")
            ElseIf Not Util.ValidatePassword(collection("new_password")) Then
                ModelState.AddModelError("", "新パスワードは半角英数字6文字-20文字で入力してください。また、英大文字、英小文字、数字の3種類の文字を含む必要があります。")
            End If


            If collection("new_password") <> collection("new_password2") Then
                ModelState.AddModelError("", "新パスワードと新パスワード(確認)が異なっています")
            End If

            If Not ModelState.IsValid Then
                Return View()
            End If

            ' パスワード情報をオブジェクトに格納
            Dim data As PasswordChangeData = New PasswordChangeData
            data.OPERATOR_ID = collection("user_id")
            data.PASSWORD = collection("new_password")

            ' パスワード情報をセッションに格納
            Session("PasswordChangeData") = data

            Return RedirectToAction("PasswordChangeConfirm", "Account")
        Else    ' 戻るボタンを押したとき
            Session("PasswordChangeData") = Nothing
            Return RedirectToAction("LogOn", "Account")
        End If


    End Function

    Public Function PasswordChangeConfirm() As ActionResult
        Dim data As PasswordChangeData = TryCast(Session("PasswordChangeData"), PasswordChangeData)

        ' パスワード変更情報を表示
        ViewData("user_id") = data.OPERATOR_ID
        ViewData("password") = "**********"

        Return View()
    End Function

    <HttpPost()> _
    Public Function PasswordChangeConfirm(ByVal collection As FormCollection) As ActionResult
        Dim data As PasswordChangeData = TryCast(Session("PasswordChangeData"), PasswordChangeData)

        If collection("button") = "保存" Then ' 保存ボタンを押したとき
            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

            ' SHA256で暗号化
            Dim encryptPassword As String = Crypt.EncryptSHA256(data.PASSWORD)

            ' データベースを更新
            Try
                dc.updateUserPassword(data.OPERATOR_ID, encryptPassword)
                dc.SubmitChanges()
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try

            ' メッセージボックスを表示
            Session("MessageBoxTitle") = "パスワード変更完了"
            Session("MessageBoxMessage") = "パスワード変更が完了しました"

            Session("PasswordChangeData") = Nothing

            Return RedirectToAction("MessageBox", "Account")
        Else ' 戻るボタンを押したとき
            Return RedirectToAction("PasswordChange", "Account")
        End If

    End Function

    <ValidateInput(False)> _
    Function Register() As ActionResult
        Dim data As RegisterModel = TryCast(Session("RegisterData"), RegisterModel)

        If Not data Is Nothing Then
            Return View(data)
        End If

        Return View()
    End Function

    <HttpPost()>
    <ValidateInput(False)> _
    Function Register(ByVal model As RegisterModel) As ActionResult
        ' 追加のバリデーション
        ' 姓（漢字）
        If Util.IncludeHarfCharacter(Util.NStr(model.KANJI_SEI)) Then
            ModelState.AddModelError("KANJI_SEI", "姓（漢字）に半角文字は使えません")
        End If

        If Util.IncludeSpecialCharacter(Util.NStr(model.KANJI_SEI)) Then
            ModelState.AddModelError("KANJI_SEI", "姓（漢字）に機種依存文字は使えません")
        End If

        ' 名（漢字）
        If Util.IncludeHarfCharacter(Util.NStr(model.KANJI_MEI)) Then
            ModelState.AddModelError("KANJI_MEI", "名（漢字）に半角文字は使えません")
        End If

        If Util.IncludeSpecialCharacter(Util.NStr(model.KANJI_MEI)) Then
            ModelState.AddModelError("KANJI_MEI", "名（漢字）に機種依存文字は使えません")
        End If

        ' 都道府県
        If Util.IncludeHarfCharacter(Util.NStr(model.ADDRESS1)) Then
            ModelState.AddModelError("ADDRESS1", "都道府県に半角文字は使えません")
        End If

        If Util.IncludeSpecialCharacter(Util.NStr(model.ADDRESS1)) Then
            ModelState.AddModelError("ADDRESS1", "都道府県に機種依存文字は使えません")
        End If

        ' 市区町村・番地
        If Util.IncludeHarfCharacter(Util.NStr(model.ADDRESS2)) Then
            ModelState.AddModelError("ADDRESS2", "市区町村・番地に半角文字は使えません")
        End If

        If Util.IncludeSpecialCharacter(Util.NStr(model.ADDRESS2)) Then
            ModelState.AddModelError("ADDRESS2", "市区町村・番地に機種依存文字は使えません")
        End If

        ' アパート・マンション名
        If Util.IncludeHarfCharacter(Util.NStr(model.ADDRESS3)) Then
            ModelState.AddModelError("ADDRESS3", "アパート・マンション名に半角文字は使えません")
        End If

        If Util.IncludeSpecialCharacter(Util.NStr(model.ADDRESS3)) Then
            ModelState.AddModelError("ADDRESS3", "アパート・マンション名に機種依存文字は使えません")
        End If

        ' パスワード
        If Util.NStr(model.PASSWORD) <> Util.NStr(model.PASSWORD2) Then
            ModelState.AddModelError("PASSWORD2", "パスワードとパスワード（確認）が一致しません。")
        End If

        Dim connStr As String = Util.GetConnectionString
        Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

        Dim list = From t In dc.GetTable(Of MstUser)() Where t.USER_ID = model.USER_ID

        If list.Count > 0 Then
            ModelState.AddModelError("UserID", "ご指定のユーザIDはすでに登録されています")
        End If

        If ModelState.IsValid Then

            Session("RegisterData") = model
            Return RedirectToAction("RegisterConfirm", "Account")
        End If

        Return View(model)
    End Function

    Function RegisterConfirm() As ActionResult
        Dim data As RegisterModel = TryCast(Session("RegisterData"), RegisterModel)

        If data Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        ' マスクしたパスワードを用意
        data.PASSWORD_CONFIRM = Util.GetMaskString(data.PASSWORD)

        Return View(data)
    End Function

    <HttpPost()>
    Function RegisterConfirm(ByVal model As RegisterModel, ByVal collection As FormCollection) As ActionResult
        If collection.Item("button") = "戻る" Then
            Return RedirectToAction("Register", "Account")
        ElseIf collection.Item("button") = "保存" Then
            Dim data As RegisterModel = TryCast(Session("RegisterData"), RegisterModel)

            If data Is Nothing Then
                Return RedirectToAction("Maintenance", "Home")
            End If

            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

            ' パスワードを暗号化
            Dim encryptedPassword As String = Crypt.EncryptSHA256(data.PASSWORD)

            ' ユーザマスタにインサート
            Try
                dc.insertUserMst(data.USER_ID,
                                 encryptedPassword,
                                 data.KANJI_SEI,
                                 data.KANJI_MEI,
                                 data.KANA_SEI,
                                 data.KANA_MEI,
                                 data.E_MAIL,
                                 data.TEL,
                                 data.URGENT_TEL,
                                 data.ZIP,
                                 data.ADDRESS1,
                                 data.ADDRESS2,
                                 data.ADDRESS3)
                dc.SubmitChanges()
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try

            ' セッションのクリア
            Session("RegisterData") = Nothing

            ' メッセージボックスの表示
            Session("MessageBoxTitle") = "ユーザ登録完了"
            Session("MessageBoxMessage") = "ユーザ登録が完了しました"
            Return RedirectToAction("MessageBox", "Account")
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function

    Function MessageBox() As ActionResult
        ViewData("MessagaBoxTitle") = Session("MessageBoxTitle")
        ViewData("MessageBoxMessage") = Session("MessageBoxMessage")

        Return View()
    End Function

    <HttpPost()>
    Function MessageBox(ByVal collection As FormCollection) As ActionResult
        Session("MessageBoxTitle") = Nothing
        Session("MessageBoxMessage") = Nothing

        Return RedirectToAction("LogOn", "Account")
    End Function
End Class
