﻿Imports System.Transactions

Public Class CartController
    Inherits System.Web.Mvc.Controller

    Function Index() As ActionResult
        ' ログイン情報を取得
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim connStr As String = Util.GetConnectionString
        Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

        Dim model As CartModel = New CartModel

        ' カート情報を読み込む
        Try
            model.Cart = From t In dc.GetTable(Of Cart)()
                         Join t2 In dc.GetTable(Of Products)() On t.PRODUCT_ID Equals t2.PRODUCT_ID
                         Where t.CUSTOMER_ID = acc.USER_ID
                         Select New CartObj With {
                             .CustomerID = t.CUSTOMER_ID,
                             .ProductID = t.PRODUCT_ID,
                             .ProductName = t2.PRODUCT_NAME,
                             .Price = t2.PRICE,
                             .Quantity = t.QUANTITY}
        Catch ex As Exception
            ' エラーが出たときはカート情報を削除する
            dc.deleteCartAll(acc.USER_ID)
            model.Cart = Nothing
        End Try

        Return View(model)
    End Function

    <HttpPost()>
    Function Index(ByVal collection As FormCollection) As ActionResult
        ' ログイン情報を取得
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If


        If collection.Item("button") = "更新" Then
            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

            ' バリデーション
            For Each key As String In collection.Keys
                If key.StartsWith("quantity") Then
                    Dim no As Integer = key.Substring("quantity".Length)
                    Dim quantity As String = collection.Item(key)

                    If Not Util.IsNumeric(quantity) Then
                        ModelState.AddModelError("", "数量は整数でご入力ください")
                    End If

                    If Not ModelState.IsValid Then
                        Return Index()
                    End If
                End If
            Next

            ' 数量の更新
            Using ts = New TransactionScope

                Try
                    For Each key As String In collection.Keys
                        If key.StartsWith("quantity") Then
                            Dim no As Integer = key.Substring("quantity".Length)
                            Dim quantity As Integer = collection.Item(key)

                            If quantity = 0 Then ' 0のときカートから削除
                                dc.DeleteCart(acc.USER_ID, no)
                            Else                 ' 数量変更のときカート情報をupdate
                                dc.UpdateCart(acc.USER_ID, no, quantity)
                            End If

                        End If
                    Next
                    dc.SubmitChanges()
                Catch ex As Exception
                    RedirectToAction("Maintenance", "Home")
                End Try
              
                ts.Complete()
            End Using

            Return Index()
        ElseIf collection.Item("button") = "レジに進む" Then
            Return RedirectToAction("Destination", "Cart")
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function

    Public Function Destination() As ActionResult
        ' ログイン情報を取得
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim connStr As String = Util.GetConnectionString
        Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

        Dim model As DestinationInfoModel = New DestinationInfoModel

        ' 顧客情報を読み込み
        Try
            model = (From t In dc.GetTable(Of MstUser)() Where t.USER_ID = acc.USER_ID
                   Select New DestinationInfoModel With {
                       .KANJI_SEI = t.KANJI_SEI,
                       .KANJI_MEI = t.KANJI_MEI,
                       .TEL = t.TEL,
                       .ZIP = t.ZIP,
                       .ADDRESS1 = t.ADDRESS1,
                       .ADDRESS2 = t.ADDRESS2,
                       .ADDRESS3 = t.ADDRESS3}).First

        Catch ex As Exception
            Return RedirectToAction("Maintenance", "Home")
        End Try
       
        Return View(model)
    End Function

    <HttpPost()>
    Public Function Destination(ByVal model As DestinationInfoModel, ByVal collection As FormCollection) As ActionResult
        ' ログイン情報を取得
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If collection.Item("button") = "確認" Then
            ' 追加のバリデーション
            ' 姓（漢字）
            If Util.IncludeHarfCharacter(Util.NStr(model.KANJI_SEI)) Then
                ModelState.AddModelError("KANJI_SEI", "姓（漢字）に半角文字は使えません")
            End If

            If Util.IncludeSpecialCharacter(Util.NStr(model.KANJI_SEI)) Then
                ModelState.AddModelError("KANJI_SEI", "姓（漢字）に機種依存文字は使えません")
            End If

            ' 名（漢字）
            If Util.IncludeHarfCharacter(Util.NStr(model.KANJI_MEI)) Then
                ModelState.AddModelError("KANJI_MEI", "名（漢字）に半角文字は使えません")
            End If

            If Util.IncludeSpecialCharacter(Util.NStr(model.KANJI_MEI)) Then
                ModelState.AddModelError("KANJI_MEI", "名（漢字）に機種依存文字は使えません")
            End If

            ' 都道府県
            If Util.IncludeHarfCharacter(Util.NStr(model.ADDRESS1)) Then
                ModelState.AddModelError("ADDRESS1", "都道府県に半角文字は使えません")
            End If

            If Util.IncludeSpecialCharacter(Util.NStr(model.ADDRESS1)) Then
                ModelState.AddModelError("ADDRESS1", "都道府県に機種依存文字は使えません")
            End If

            ' 市区町村・番地
            If Util.IncludeHarfCharacter(Util.NStr(model.ADDRESS2)) Then
                ModelState.AddModelError("ADDRESS2", "市区町村・番地に半角文字は使えません")
            End If

            If Util.IncludeSpecialCharacter(Util.NStr(model.ADDRESS2)) Then
                ModelState.AddModelError("ADDRESS2", "市区町村・番地に機種依存文字は使えません")
            End If

            ' アパート・マンション名
            If Util.IncludeHarfCharacter(Util.NStr(model.ADDRESS3)) Then
                ModelState.AddModelError("ADDRESS3", "アパート・マンション名に半角文字は使えません")
            End If

            If Util.IncludeSpecialCharacter(Util.NStr(model.ADDRESS3)) Then
                ModelState.AddModelError("ADDRESS3", "アパート・マンション名に機種依存文字は使えません")
            End If

            If ModelState.IsValid Then
                Session("DestinationData") = model
                Return RedirectToAction("Delivery", "Cart")
            Else
                Return View(model)
            End If

        Else
            Return RedirectToAction("Maintenance", "Home")
        End If

    End Function

    Function Delivery() As ActionResult
        Return View()
    End Function

    <HttpPost()>
    Function Delivery(ByVal collection As FormCollection) As ActionResult
        ' ログイン情報を取得
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If collection.Item("button") = "確定" Then
            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

            ' 送付先情報を取得
            Dim model As DestinationInfoModel = TryCast(Session("DestinationData"), DestinationInfoModel)

            If model Is Nothing Then
                Return RedirectToAction("Maintenance", "Home")
            End If

            ' カート情報を取得
            Dim modelCart As CartModel = New CartModel

            Try
                modelCart.Cart = From t In dc.GetTable(Of Cart)()
                             Join t2 In dc.GetTable(Of Products)() On t.PRODUCT_ID Equals t2.PRODUCT_ID
                             Where t.CUSTOMER_ID = acc.USER_ID
                             Select New CartObj With {
                                 .CustomerID = t.CUSTOMER_ID,
                                 .ProductID = t.PRODUCT_ID,
                                 .ProductName = t2.PRODUCT_NAME,
                                 .Price = t2.PRICE,
                                 .Quantity = t.QUANTITY}

            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try

            Dim OrderID As Integer
            Dim OrderNo As Integer = 1

            ' 注文情報を登録
            Using ts = New TransactionScope
                Try
                    dc.insertOrders(OrderID, acc.USER_ID, model.KANJI_SEI, model.KANJI_MEI, model.TEL, model.ZIP, model.ADDRESS1, model.ADDRESS2, model.ADDRESS3)

                    For Each item In modelCart.Cart
                        dc.InsertOrderDetails(OrderID, OrderNo, item.ProductName, item.Price, item.Quantity)

                        OrderNo += 1
                    Next

                    dc.deleteCartAll(acc.USER_ID)
                    dc.SubmitChanges()
                Catch ex As Exception
                    RedirectToAction("Maintenance", "Home")
                End Try

                ts.Complete()
            End Using


            Return RedirectToAction("Thankyou", "Cart")
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If

    End Function

    Function Thankyou() As ActionResult
        Return View()
    End Function

End Class