﻿Imports System.Data.Linq
Imports WebShopping
Imports System.Transactions

<HandleError()> _
Public Class UserController
    Inherits System.Web.Mvc.Controller

    Function UserInfo() As ActionResult
        Return View()
    End Function

    <ValidateInput(False)> _
    Function EditUserInfo() As ActionResult
        ' ログイン情報を取得
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If


        Dim data As EditUserInfoModel = TryCast(Session("EditUserInfoData"), EditUserInfoModel)
        Dim model As EditUserInfoModel

        If data Is Nothing Then
            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

            model = GetUserInfo(dc, acc.USER_ID)

            ' 該当データがないときはエラー
            If model Is Nothing Then
                Return RedirectToAction("Maintenance", "Home")
            End If
        Else
            model = data
        End If
        
        Return View(model)
    End Function

    <HttpPost()>
    <ValidateInput(False)> _
    Function EditUserInfo(ByVal model As EditUserInfoModel, ByVal colleaction As FormCollection) As ActionResult
        ' ログイン情報を取得
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If colleaction.Item("button") = "リセット" Then

            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)
            ' データを読み込む
            model = Nothing
            ModelState.Clear()
            model = GetUserInfo(dc, acc.USER_ID)


            ' 該当データがないときはエラー
            If model Is Nothing Then
                Return RedirectToAction("Maintenance", "Home")
            End If

            Return View(model)
        ElseIf colleaction.Item("button") = "確認" Then
            ' 追加のバリデーション
            ' 姓（漢字）
            If Util.IncludeHarfCharacter(Util.NStr(model.KANJI_SEI)) Then
                ModelState.AddModelError("KANJI_SEI", "姓（漢字）に半角文字は使えません")
            End If

            If Util.IncludeSpecialCharacter(Util.NStr(model.KANJI_SEI)) Then
                ModelState.AddModelError("KANJI_SEI", "姓（漢字）に機種依存文字は使えません")
            End If

            ' 名（漢字）
            If Util.IncludeHarfCharacter(Util.NStr(model.KANJI_MEI)) Then
                ModelState.AddModelError("KANJI_MEI", "名（漢字）に半角文字は使えません")
            End If

            If Util.IncludeSpecialCharacter(Util.NStr(model.KANJI_MEI)) Then
                ModelState.AddModelError("KANJI_MEI", "名（漢字）に機種依存文字は使えません")
            End If

            ' 都道府県
            If Util.IncludeHarfCharacter(Util.NStr(model.ADDRESS1)) Then
                ModelState.AddModelError("ADDRESS1", "都道府県に半角文字は使えません")
            End If

            If Util.IncludeSpecialCharacter(Util.NStr(model.ADDRESS1)) Then
                ModelState.AddModelError("ADDRESS1", "都道府県に機種依存文字は使えません")
            End If

            ' 市区町村・番地
            If Util.IncludeHarfCharacter(Util.NStr(model.ADDRESS2)) Then
                ModelState.AddModelError("ADDRESS2", "市区町村・番地に半角文字は使えません")
            End If

            If Util.IncludeSpecialCharacter(Util.NStr(model.ADDRESS2)) Then
                ModelState.AddModelError("ADDRESS2", "市区町村・番地に機種依存文字は使えません")
            End If

            ' アパート・マンション名
            If Util.IncludeHarfCharacter(Util.NStr(model.ADDRESS3)) Then
                ModelState.AddModelError("ADDRESS3", "アパート・マンション名に半角文字は使えません")
            End If

            If Util.IncludeSpecialCharacter(Util.NStr(model.ADDRESS3)) Then
                ModelState.AddModelError("ADDRESS3", "アパート・マンション名に機種依存文字は使えません")
            End If

            model.USER_ID = acc.USER_ID

            If ModelState.IsValid Then
                Session("EditUserInfoData") = model
                Return RedirectToAction("EditUserInfoConfirm", "User")
            Else
                Return View(model)
            End If

        Else
            Return RedirectToAction("Maintenance", "Home")
        End If

    End Function

    Private Function GetUserInfo(ByVal dc As DataContext, ByVal userID As String) As EditUserInfoModel
        Dim model As EditUserInfoModel

        ' 顧客情報の読み込み
        Try
            model = (From t In dc.GetTable(Of MstUser)() Where t.USER_ID = userID
              Select New EditUserInfoModel With {
                  .USER_ID = t.USER_ID,
                  .KANJI_SEI = t.KANJI_SEI,
                  .KANJI_MEI = t.KANJI_MEI,
                  .KANA_SEI = t.KANA_SEI,
                  .KANA_MEI = t.KANA_MEI,
                  .E_MAIL = t.E_MAIL,
                  .TEL = t.TEL,
                  .URGENT_TEL = t.URGENT_TEL,
                  .ZIP = t.ZIP,
                  .ADDRESS1 = t.ADDRESS1,
                  .ADDRESS2 = t.ADDRESS2,
                  .ADDRESS3 = t.ADDRESS3
              }).First
        Catch ex As Exception
            ' 該当データがないときはNothingを返す
            Return Nothing
        End Try

        Return model
    End Function

    Function EditUserInfoConfirm() As ActionResult
        ' ログイン情報を取得
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim data As EditUserInfoModel = TryCast(Session("EditUserInfoData"), EditUserInfoModel)

        If data Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Return View(data)
    End Function

    <HttpPost()>
    Function EditUserInfoConfirm(ByVal model As EditUserInfoModel, ByVal collection As FormCollection) As ActionResult
        If collection.Item("button") = "戻る" Then
            Return RedirectToAction("EditUserInfo", "User")
        ElseIf collection.Item("button") = "保存" Then
            Dim data As EditUserInfoModel = TryCast(Session("EditUserInfoData"), EditUserInfoModel)

            If data Is Nothing Then
                Return RedirectToAction("Maintenance", "Home")
            End If

            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)


            ' ユーザマスタを更新
            Try
                dc.updateUserMst(data.USER_ID,
                                  data.KANJI_SEI,
                                  data.KANJI_MEI,
                                  data.KANA_SEI,
                                  data.KANA_MEI,
                                  data.E_MAIL,
                                  data.TEL,
                                  data.URGENT_TEL,
                                  data.ZIP,
                                  data.ADDRESS1,
                                  data.ADDRESS2,
                                  data.ADDRESS3)
                dc.SubmitChanges()
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try

            ' セッションのクリア
            Session("EditUserInfoData") = Nothing

            ' メッセージボックスの表示
            Session("MessageBoxTitle") = "ユーザ情報更新完了"
            Session("MessageBoxMessage") = "ユーザ情報更新が完了しました"
            Return RedirectToAction("MessageBox", "User")
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function

    Function EditPassword() As ActionResult
        ' ログイン情報を取得
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If


        Dim data As EditUserPasswordModel = TryCast(Session("EditUserPasswordData"), EditUserPasswordModel)
        
        Return View(data)
    End Function

    <HttpPost()>
    Function EditPassword(ByVal model As EditUserPasswordModel, ByVal colleaction As FormCollection) As ActionResult
        ' ログイン情報を取得
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        ' 追加バリデーション
        ' パスワード
        If Util.NStr(model.PASSWORD) <> Util.NStr(model.PASSWORD2) Then
            ModelState.AddModelError("PASSWORD2", "パスワードとパスワード（確認）が一致しません。")
        End If

        If ModelState.IsValid Then
            Session("EditUserPasswordData") = model
            Return RedirectToAction("EditPasswordConfirm", "User")
        Else
            Return View(model)
        End If


    End Function

    Function EditPasswordConfirm() As ActionResult
        ' ログイン情報を取得
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim data As EditUserPasswordModel = TryCast(Session("EditUserPasswordData"), EditUserPasswordModel)

        If data Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        ' マスクしたパスワードを用意
        data.PASSWORD_CONFIRM = Util.GetMaskString(data.PASSWORD)

        Return View(data)
    End Function

    <HttpPost()>
    Function EditPasswordConfirm(ByVal model As EditUserPasswordModel, ByVal collection As FormCollection) As ActionResult
        ' ログイン情報を取得
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If collection.Item("button") = "戻る" Then
            Return RedirectToAction("EditPassword", "User")
        ElseIf collection.Item("button") = "保存" Then
            Dim data As EditUserPasswordModel = TryCast(Session("EditUserPasswordData"), EditUserPasswordModel)

            If data Is Nothing Then
                Return RedirectToAction("Maintenance", "Home")
            End If

            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)
            ' パスワードを暗号化
            Dim encryptedPassword As String = Crypt.EncryptSHA256(data.PASSWORD)

            ' ユーザマスタを更新
            Try
                dc.updateUserPassword(acc.USER_ID, encryptedPassword)
                dc.SubmitChanges()
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try

            ' セッションのクリア
            Session("EditUserInfoData") = Nothing

            ' メッセージボックスの表示
            Session("MessageBoxTitle") = "パスワード更新完了"
            Session("MessageBoxMessage") = "パスワードの更新が完了しました"
            Return RedirectToAction("MessageBox", "User")
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function

    Function Orders() As ActionResult
        ' ログイン情報を取得
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim connStr As String = Util.GetConnectionString
        Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

        Dim model As OrdersModel = New OrdersModel

        model.Orders = From t In dc.GetTable(Of Orders)() Where t.CUSTOMER_ID = acc.USER_ID


        Return View(model)
    End Function

    Function OrderDetails(ByVal id As Integer) As ActionResult
        ' ログイン情報を取得
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim connStr As String = Util.GetConnectionString
        Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

        Dim list = From t In dc.GetTable(Of Orders)() Where t.CUSTOMER_ID = acc.USER_ID AndAlso t.ORDER_ID = id
        ' 自分の履歴でないときはエラー画面
        If list.Count = 0 Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim model As OrderDetailsModel = New OrderDetailsModel

        Try
            model.Details = From t In dc.GetTable(Of OrderDetails)()
                    Where t.ORDER_ID = id Order By t.ORDER_NO Ascending
                        Select New OrderDetailsObj With {
                            .OrderID = t.ORDER_ID,
                            .OrderNo = t.ORDER_NO,
                            .ProductName = t.PRODUCT_NAME,
                            .Price = t.PRICE,
                            .Quantity = t.QUANTITY}
        Catch ex As Exception
            Return RedirectToAction("Maintenance", "Home")
        End Try

        Return View(model)
    End Function

    Function MessageBox() As ActionResult
        ViewData("MessagaBoxTitle") = Session("MessageBoxTitle")
        ViewData("MessageBoxMessage") = Session("MessageBoxMessage")

        Return View()
    End Function

    <HttpPost()>
    Function MessageBox(ByVal collection As FormCollection) As ActionResult
        Session("MessageBoxTitle") = Nothing
        Session("MessageBoxMessage") = Nothing

        Return RedirectToAction("Index", "Home")
    End Function
End Class
