﻿Public Class OperatorController
    Inherits System.Web.Mvc.Controller

    Function Index() As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If
        Return View()
    End Function

    <HttpPost()>
    Function Index(ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If collection.Item("button") = "検索" Then
            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

            Dim model As OperatorListModel = New OperatorListModel

            ViewData("search_value") = collection.Item("search")

            model.MstOperator = From t In dc.GetTable(Of MstOperator)() Where t.OPERATOR_ID.Contains(collection.Item("search")) Order By t.OPERATOR_ID Ascending

            Return View(model)
        ElseIf collection.Item("button") = "新規登録" Then
            Return RedirectToAction("Create", "Operator")
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function

    Function Create() As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim data As CreateOperatorModel = TryCast(Session("CreateOperatorData"), CreateOperatorModel)

        If Not data Is Nothing Then
            Return View(data)
        End If


        Return View()
    End Function

    <HttpPost()>
    Function Create(ByVal model As CreateOperatorModel, ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If collection.Item("button") = "戻る" Then
            Session("CreateOperatorData") = Nothing
            Return RedirectToAction("Index", "Operator")
        ElseIf collection.Item("button") = "確認" Then
            ' 追加のバリデーション
            If Util.IncludeSpecialCharacter(Util.NStr(model.OperatorName)) Then
                ModelState.AddModelError("OperatorName", "オペレータ名に機種依存文字は使えません")
            End If

            If Not Util.ValidatePassword(Util.NStr(model.Password)) Then
                ModelState.AddModelError("PASSWORD", "パスワードは半角英数字6文字-20文字で入力してください。また、英大文字、英小文字、数字の3種類の文字を含む必要があります。")
            End If

            ' パスワード
            If Util.NStr(model.Password) <> Util.NStr(model.Password2) Then
                ModelState.AddModelError("PASSWORD2", "パスワードとパスワード（確認）が一致しません。")
            End If

            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

            Dim operatorID As String = Util.NStr(model.OperatorID).Trim

            Dim list = From t In dc.GetTable(Of MstOperator)() Where t.OPERATOR_ID = operatorID

            If list.Count > 0 Then
                ModelState.AddModelError("OperatorID", "すでに登録されているオペレータIDです")
            End If

            If ModelState.IsValid Then
                Session("CreateOperatorData") = model
                Return RedirectToAction("CreateConfirm", "Operator")
            End If



            Return View(model)
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If


    End Function

    Function CreateConfirm() As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim data As CreateOperatorModel = TryCast(Session("CreateOperatorData"), CreateOperatorModel)

        If data Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        ' マスクしたパスワードを用意
        data.PasswordConfirm = Util.GetMaskString(data.Password)

        Return View(data)
    End Function

    <HttpPost()>
    Function CreateConfirm(ByVal model As CreateOperatorModel, ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If
        If collection.Item("button") = "戻る" Then
            Return RedirectToAction("Create", "Operator")
        ElseIf collection.Item("button") = "保存" Then

            Dim data As CreateOperatorModel = TryCast(Session("CreateOperatorData"), CreateOperatorModel)

            If data Is Nothing Then
                Return RedirectToAction("Maintenance", "Home")
            End If

            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

            ' パスワードを暗号化
            Dim encryptedPassword As String = Crypt.EncryptSHA256(data.PASSWORD)

            ' オペレータマスタにインサート
            Try
                dc.insertOperatorMst(data.OperatorID,
                                    encryptedPassword,
                                    data.OperatorName)
                dc.SubmitChanges()
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try

            ' セッションのクリア
            Session("CreateOperatorData") = Nothing

            ' メッセージボックスの表示
            Session("MessageBoxTitle") = "オペレータ登録完了"
            Session("MessageBoxMessage") = "オペレータ登録が完了しました"
            Return RedirectToAction("MessageBox", "Home")
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If

        Return View()
    End Function

    Function Edit(ByVal id As String) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim obj As EditOperatorModel = TryCast(Session("EditOperatorData"), EditOperatorModel)

        Dim connStr As String = Util.GetConnectionString
        Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

        Dim model As EditOperatorModel = New EditOperatorModel

        If obj Is Nothing Then

            Try
                model = (From t In dc.GetTable(Of MstOperator)() Where t.OPERATOR_ID = id
                            Select New EditOperatorModel With {
                                .OperatorID = t.OPERATOR_ID,
                                .OperatorName = t.OPERATOR_NAME,
                                .IsLock = t.IS_LOCK,
                                .Deleted = t.DELETED}).First
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try
        Else
            Try
                model = (From t In dc.GetTable(Of MstOperator)() Where t.OPERATOR_ID = id
                            Select New EditOperatorModel With {
                                .OperatorID = t.OPERATOR_ID,
                                .OperatorName = t.OPERATOR_NAME,
                                .IsLock = t.IS_LOCK,
                                .Deleted = t.DELETED}).First
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try

            model = obj
        End If

        Return View(model)
    End Function

    <HttpPost()>
    Function Edit(ByVal id As String, ByVal model As EditOperatorModel, ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If collection.Item("button") = "戻る" Then
            Return RedirectToAction("Index", "Operator")
        ElseIf collection.Item("button") = "確認" Then

            ' 追加のバリデーション
            If Util.IncludeSpecialCharacter(Util.NStr(model.OperatorName)) Then
                ModelState.AddModelError("OperatorName", "オペレータ名に機種依存文字は使えません")
            End If

            model.OperatorID = id

            If ModelState.IsValid Then

                Session("EditOperatorData") = model
                Return RedirectToAction("EditConfirm", "Operator")
            End If

            Return View(model)
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function

    Function EditConfirm() As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim obj As EditOperatorModel = TryCast(Session("EditOperatorData"), EditOperatorModel)

        If obj Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Return View(obj)
    End Function

    <HttpPost()>
    Function EditConfirm(ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim obj As EditOperatorModel = TryCast(Session("EditOperatorData"), EditOperatorModel)

        If obj Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If collection.Item("button") = "戻る" Then
            Return RedirectToAction("Edit/" & obj.OperatorID, "Operator")
        ElseIf collection.Item("button") = "保存" Then
            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

            ' オペレータマスタの更新
            Try
                dc.updateOperatorMst(obj.OperatorID, obj.OperatorName, obj.IsLock, obj.Deleted)
                dc.SubmitChanges()
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try
            ' セッションのクリア
            Session("EditOperatorData") = Nothing

            ' メッセージボックスの表示
            Session("MessageBoxTitle") = "オペレータ情報更新完了"
            Session("MessageBoxMessage") = "オペレータ情報の更新が完了しました"
            Return RedirectToAction("MessageBox", "Home")
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function

    Function PasswordChange(ByVal id As String) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim obj As PasswordOperatorModel = TryCast(Session("PasswordOperatorData"), PasswordOperatorModel)

        Dim connStr As String = Util.GetConnectionString
        Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

        Dim model As PasswordOperatorModel = New PasswordOperatorModel

        If obj Is Nothing Then

            Try
                model = (From t In dc.GetTable(Of MstOperator)() Where t.OPERATOR_ID = id
                            Select New PasswordOperatorModel With {
                                .OperatorID = t.OPERATOR_ID}).First
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try
        Else
            Try
                model = (From t In dc.GetTable(Of MstOperator)() Where t.OPERATOR_ID = id
                            Select New PasswordOperatorModel With {
                                .OperatorID = t.OPERATOR_ID}).First
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try

            model = obj
        End If

        Return View(model)
    End Function

    <HttpPost()>
    Function PasswordChange(ByVal id As String, ByVal model As PasswordOperatorModel, ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If collection.Item("button") = "戻る" Then
            Return RedirectToAction("Index", "Operator")
        ElseIf collection.Item("button") = "確認" Then

            ' 追加のバリデーション
            If Not Util.ValidatePassword(Util.NStr(model.Password)) Then
                ModelState.AddModelError("PASSWORD", "パスワードは半角英数字6文字-20文字で入力してください。また、英大文字、英小文字、数字の3種類の文字を含む必要があります。")
            End If

            ' パスワード
            If Util.NStr(model.Password) <> Util.NStr(model.Password2) Then
                ModelState.AddModelError("PASSWORD2", "パスワードとパスワード（確認）が一致しません。")
            End If

            model.OperatorID = id

            If ModelState.IsValid Then
                Session("PasswordOperatorData") = model
                Return RedirectToAction("PasswordChangeConfirm", "Operator")
            End If

            Return View(model)
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function

    Function PasswordChangeConfirm() As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim obj As PasswordOperatorModel = TryCast(Session("PasswordOperatorData"), PasswordOperatorModel)

        If obj Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        obj.PasswordConfirm = Util.GetMaskString(obj.Password)

        Return View(obj)
    End Function

    <HttpPost()>
    Function PasswordChangeConfirm(ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim obj As PasswordOperatorModel = TryCast(Session("PasswordOperatorData"), PasswordOperatorModel)

        If obj Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If


        If collection.Item("button") = "戻る" Then
            Return RedirectToAction("PasswordChange/" & obj.OperatorID, "Operator")
        ElseIf collection.Item("button") = "保存" Then
            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

            Dim encryptedPassword As String = Crypt.EncryptSHA256(obj.Password)

            ' オペレータマスタの更新
            Try
                dc.updateOperatorPassword(obj.OperatorID, encryptedPassword)
                dc.SubmitChanges()
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try
            ' セッションのクリア
            Session("PasswordOperatorData") = Nothing

            ' メッセージボックスの表示
            Session("MessageBoxTitle") = "パスワード更新完了"
            Session("MessageBoxMessage") = "オペレータのパスワードの更新が完了しました"
            Return RedirectToAction("MessageBox", "Home")
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function
End Class