﻿Imports System.Transactions


Public Class ProductController
    Inherits System.Web.Mvc.Controller


    Function Index() As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Return View()
    End Function

    Function Category() As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim connStr As String = Util.GetConnectionString
        Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

        Dim model As CategoryListModel = New CategoryListModel

        model.Category = From t In dc.GetTable(Of Categories)() Order By t.SORT_NO Ascending

        Return View(model)
    End Function

    <HttpPost()>
    Function Category(ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If collection.Item("button") = "新規登録" Then
            Return RedirectToAction("NewCategory", "Product")
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function

    Function NewCategory() As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim data As CategoryModel = TryCast(Session("NewCategoryData"), CategoryModel)

        If Not data Is Nothing Then
            Return View(data)
        End If


        Return View()
    End Function

    <HttpPost()>
    Function NewCategory(ByVal model As CategoryModel, ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If collection.Item("button") = "戻る" Then
            Session("NewCategoryData") = Nothing
            Return RedirectToAction("Category", "Product")
        ElseIf collection.Item("button") = "確認" Then
            ' 追加のバリデーション
            If Util.IncludeSpecialCharacter(Util.NStr(model.CategoryName)) Then
                ModelState.AddModelError("OperatorName", "オペレータ名に機種依存文字は使えません")
            End If

            If ModelState.IsValid Then
                Session("NewCategoryData") = model
                Return RedirectToAction("NewCategoryConfirm", "Product")
            End If

            Return View(model)
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If

    End Function

    Function NewCategoryConfirm() As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim data As CategoryModel = TryCast(Session("NewCategoryData"), CategoryModel)

        If data Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Return View(data)
    End Function

    <HttpPost()>
    Function NewCategoryConfirm(ByVal model As CategoryModel, ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If
        If collection.Item("button") = "戻る" Then
            Return RedirectToAction("NewCategory", "Product")
        ElseIf collection.Item("button") = "保存" Then

            Dim data As CategoryModel = TryCast(Session("NewCategoryData"), CategoryModel)

            If data Is Nothing Then
                Return RedirectToAction("Maintenance", "Home")
            End If

            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)


            ' カテゴリマスタにインサート
            Try
                dc.insertCategory(data.CategoryName,
                                    data.SortNo)
                dc.SubmitChanges()
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try

            ' セッションのクリア
            Session("NewCategoryData") = Nothing

            ' メッセージボックスの表示
            Session("MessageBoxTitle") = "カテゴリ登録完了"
            Session("MessageBoxMessage") = "カテゴリの登録が完了しました"
            Return RedirectToAction("MessageBox", "Home")
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If

        Return View()
    End Function

    Function DeleteCategory(ByVal id As String) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim connStr As String = Util.GetConnectionString
        Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

        Dim model As CategoryModel = New CategoryModel

        Try
            model = (From t In dc.GetTable(Of Categories)() Where t.CATEGORY_ID = id
                        Select New CategoryModel With {
                            .CategoryID = t.CATEGORY_ID,
                            .CategoryName = t.CATEGORY_NAME,
                            .SortNo = t.SORT_NO}).First

        Catch ex As Exception
            Return RedirectToAction("Maintenance", "Home")
        End Try

        Return View(model)
    End Function

    <HttpPost()>
    Function DeleteCategory(ByVal id As String, ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If
        If collection.Item("button") = "戻る" Then
            Return RedirectToAction("Category", "Product")
        ElseIf collection.Item("button") = "削除" Then
            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)
            Dim model As CategoryModel = New CategoryModel

            Try
                model = (From t In dc.GetTable(Of Categories)() Where t.CATEGORY_ID = id
                        Select New CategoryModel With {
                            .CategoryID = t.CATEGORY_ID,
                            .CategoryName = t.CATEGORY_NAME,
                            .SortNo = t.SORT_NO}).First

            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try

            ' カテゴリと商品の削除
            Try
                Using ts = New TransactionScope
                    dc.deleteCategory(id)
                    dc.deleteProductByCategory(id)
                    dc.SubmitChanges()
                    ts.Complete()
                End Using
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try

            ' メッセージボックスの表示
            Session("MessageBoxTitle") = "カテゴリ削除完了"
            Session("MessageBoxMessage") = "カテゴリの削除が完了しました"
            Return RedirectToAction("MessageBox", "Home")
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function

    Function EditCategory(ByVal id As String) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim obj As CategoryModel = TryCast(Session("EditCategoryData"), CategoryModel)

        Dim connStr As String = Util.GetConnectionString
        Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

        Dim model As CategoryModel = New CategoryModel

        If obj Is Nothing Then

            Try
                model = (From t In dc.GetTable(Of Categories)() Where t.CATEGORY_ID = id
                            Select New CategoryModel With {
                                .CategoryID = t.CATEGORY_ID,
                                .CategoryName = t.CATEGORY_NAME,
                                .SortNo = t.SORT_NO}).First
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try
        Else
            Try
                model = (From t In dc.GetTable(Of Categories)() Where t.CATEGORY_ID = id
                            Select New CategoryModel With {
                                .CategoryID = t.CATEGORY_ID,
                                .CategoryName = t.CATEGORY_NAME,
                                .SortNo = t.SORT_NO}).First
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try

            model = obj
        End If

        Return View(model)
    End Function

    <HttpPost()>
    Function EditCategory(ByVal id As String, ByVal model As CategoryModel, ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If collection.Item("button") = "戻る" Then
            Return RedirectToAction("Category", "Product")
        ElseIf collection.Item("button") = "確認" Then
            ' 追加のバリデーション
            If Util.IncludeSpecialCharacter(Util.NStr(model.CategoryName)) Then
                ModelState.AddModelError("OperatorName", "オペレータ名に機種依存文字は使えません")
            End If

            model.CategoryID = id

            If ModelState.IsValid Then
                Session("EditCategoryData") = model
                Return RedirectToAction("EditCategoryConfirm", "Product")
            End If

            Return View(model)
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function

    Function EditCategoryConfirm() As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim obj As CategoryModel = TryCast(Session("EditCategoryData"), CategoryModel)

        If obj Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Return View(obj)
    End Function

    <HttpPost()>
    Function EditCategoryConfirm(ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim obj As CategoryModel = TryCast(Session("EditCategoryData"), CategoryModel)

        If obj Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If collection.Item("button") = "戻る" Then
            Return RedirectToAction("EditCategory/" & obj.CategoryID, "Product")
        ElseIf collection.Item("button") = "保存" Then
            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

            ' ユーザマスタの更新
            Try
                dc.updateCategory(obj.CategoryID, obj.CategoryName, obj.SortNo)
                dc.SubmitChanges()
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try
            ' セッションのクリア
            Session("EditCategoryData") = Nothing

            ' メッセージボックスの表示
            Session("MessageBoxTitle") = "カテゴリ更新完了"
            Session("MessageBoxMessage") = "カテゴリの更新が完了しました"
            Return RedirectToAction("MessageBox", "Home")
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function


    Function Product() As ActionResult
        Dim connStr As String = Util.GetConnectionString
        Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

        Dim list = From t In dc.GetTable(Of Categories)() Order By t.SORT_NO Ascending

        Dim ctrl As List(Of SelectListItem) = New List(Of SelectListItem)

        For Each item In list
            ctrl.Add(New SelectListItem() With {.Text = item.CATEGORY_NAME, .Value = item.CATEGORY_ID})
        Next

        ViewData("categories") = New SelectList(ctrl, "Value", "Text")


        Return View()
    End Function

    <HttpPost()>
    Function Product(ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If collection.Item("button") = "新規登録" Then
            Return RedirectToAction("NewProduct", "Product")
        ElseIf collection.Item("button") = "検索" Then
            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

            Dim model As ProductListModel = New ProductListModel

            Dim Categories As Integer = CInt(collection.Item("categories"))

            model.Product = From t In dc.GetTable(Of Products)() Where t.CATEGORY_ID = Categories AndAlso (collection.Item("product") = "" OrElse t.PRODUCT_NAME.Contains(collection.Item("product"))) Order By t.SORT_NO Ascending

            Dim list = From t In dc.GetTable(Of Categories)() Order By t.SORT_NO Ascending

            Dim ctrl As List(Of SelectListItem) = New List(Of SelectListItem)

            For Each item In list
                ctrl.Add(New SelectListItem() With {.Text = item.CATEGORY_NAME, .Value = item.CATEGORY_ID})
            Next

            ViewData("product_value") = collection.Item("product")
            ViewData("categories") = New SelectList(ctrl, "Value", "Text", Categories)

            Return View(model)
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function

    Function NewProduct() As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim data As ProductModel = TryCast(Session("NewProductData"), ProductModel)

        Dim connStr As String = Util.GetConnectionString
        Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

        Dim list = From t In dc.GetTable(Of Categories)() Order By t.SORT_NO Ascending

        Dim ctrl As List(Of SelectListItem) = New List(Of SelectListItem)

        For Each item In list
            ctrl.Add(New SelectListItem() With {.Text = item.CATEGORY_NAME, .Value = item.CATEGORY_ID})
        Next

        If Not data Is Nothing Then
            ViewData("CategoryID") = New SelectList(ctrl, "Value", "Text", data.CategoryID)
        Else
            ViewData("CategoryID") = New SelectList(ctrl, "Value", "Text")
        End If


        If Not data Is Nothing Then
            Return View(data)
        End If


        Return View()
    End Function

    <HttpPost()>
    Function NewProduct(ByVal model As ProductModel, ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If collection.Item("button") = "戻る" Then
            Session("NewProductData") = Nothing
            Return RedirectToAction("Product", "Product")
        ElseIf collection.Item("button") = "確認" Then
            ' 追加のバリデーション
            If Util.IncludeSpecialCharacter(Util.NStr(model.ProductName)) Then
                ModelState.AddModelError("ProductName", "商品名に機種依存文字は使えません")
            End If

            If Util.IncludeSpecialCharacter(Util.NStr(model.ProductDescription)) Then
                ModelState.AddModelError("ProductDescription", "商品詳細に機種依存文字は使えません")
            End If


            If ModelState.IsValid Then
                Dim connStr As String = Util.GetConnectionString
                Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

                model.CategoryName = (From t In dc.GetTable(Of Categories)() Where t.CATEGORY_ID = model.CategoryID Select t.CATEGORY_NAME).First

                Session("NewProductData") = model
                Return RedirectToAction("NewProductConfirm", "Product")
            End If

            Return View(model)
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If

    End Function

    Function NewProductConfirm() As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim data As ProductModel = TryCast(Session("NewProductData"), ProductModel)

        If data Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Return View(data)
    End Function

    <HttpPost()>
    Function NewProductConfirm(ByVal model As ProductModel, ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If
        If collection.Item("button") = "戻る" Then
            Return RedirectToAction("NewProduct", "Product")
        ElseIf collection.Item("button") = "保存" Then

            Dim data As ProductModel = TryCast(Session("NewProductData"), ProductModel)

            If data Is Nothing Then
                Return RedirectToAction("Maintenance", "Home")
            End If

            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)


            ' 商品マスタにインサート
            Try
                dc.insertProduct(data.ProductName, data.ProductDescription, data.Price, data.CategoryID, data.SortNo)
                dc.SubmitChanges()
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try

            ' セッションのクリア
            Session("NewProductModelData") = Nothing

            ' メッセージボックスの表示
            Session("MessageBoxTitle") = "商品登録完了"
            Session("MessageBoxMessage") = "商品の登録が完了しました"
            Return RedirectToAction("MessageBox", "Home")
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If

        Return View()
    End Function

    Function DeleteProduct(ByVal id As String) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim connStr As String = Util.GetConnectionString
        Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

        Dim model As ProductModel = New ProductModel

        Try
            model = (From t In dc.GetTable(Of Products)()
                        Join t2 In dc.GetTable(Of Categories)() On t.CATEGORY_ID Equals t2.CATEGORY_ID Where t.PRODUCT_ID = id
                        Select New ProductModel With {
                            .ProductID = t.PRODUCT_ID,
                            .ProductName = t.PRODUCT_NAME,
                            .ProductDescription = t.PRODUCT_DESCRIPTION,
                            .Price = CStr(t.PRICE),
                            .CategoryID = t.CATEGORY_ID,
                            .CategoryName = t2.CATEGORY_NAME,
                            .SortNo = t.SORT_NO
                    }).First

        Catch ex As Exception
            Return RedirectToAction("Maintenance", "Home")
        End Try

        Return View(model)
    End Function

    <HttpPost()>
    Function DeleteProduct(ByVal id As String, ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If
        If collection.Item("button") = "戻る" Then
            Return RedirectToAction("Product", "Product")
        ElseIf collection.Item("button") = "削除" Then
            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)
            Dim model As ProductModel = New ProductModel

            Try
                model = (From t In dc.GetTable(Of Products)()
                        Join t2 In dc.GetTable(Of Categories)() On t.CATEGORY_ID Equals t2.CATEGORY_ID
                            Where (t.PRODUCT_ID = id)
                        Select New ProductModel With {
                            .ProductID = t.PRODUCT_ID,
                            .ProductName = t.PRODUCT_NAME,
                            .ProductDescription = t.PRODUCT_DESCRIPTION,
                            .Price = t.PRICE,
                            .CategoryID = t.CATEGORY_ID,
                            .CategoryName = t2.CATEGORY_NAME,
                            .SortNo = t.SORT_NO}).First

            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try

            ' 商品の削除
            Try
                Using ts = New TransactionScope
                    dc.deleteProduct(id)
                    dc.SubmitChanges()
                    ts.Complete()
                End Using
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try

            ' メッセージボックスの表示
            Session("MessageBoxTitle") = "商品削除完了"
            Session("MessageBoxMessage") = "商品の削除が完了しました"
            Return RedirectToAction("MessageBox", "Home")
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function

    Function EditProduct(ByVal id As String) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim obj As ProductModel = TryCast(Session("EditProductData"), ProductModel)

        Dim connStr As String = Util.GetConnectionString
        Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

        Dim list = From t In dc.GetTable(Of Categories)() Order By t.SORT_NO Ascending

        Dim ctrl As List(Of SelectListItem) = New List(Of SelectListItem)

        For Each item In list
            ctrl.Add(New SelectListItem() With {.Text = item.CATEGORY_NAME, .Value = item.CATEGORY_ID})
        Next

        Dim model As ProductModel = New ProductModel

        If obj Is Nothing Then

            Try
                model = (From t In dc.GetTable(Of Products)() Where t.PRODUCT_ID = id
                            Select New ProductModel With {
                                .ProductID = t.PRODUCT_ID,
                                .ProductName = t.PRODUCT_NAME,
                                .ProductDescription = t.PRODUCT_DESCRIPTION,
                                .CategoryID = t.CATEGORY_ID,
                                .Price = t.PRICE,
                                .SortNo = t.SORT_NO}).First
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try


        Else
            Try
                model = (From t In dc.GetTable(Of Products)() Where t.PRODUCT_ID = id
                            Select New ProductModel With {
                                .ProductID = t.PRODUCT_ID,
                                .ProductName = t.PRODUCT_NAME,
                                .ProductDescription = t.PRODUCT_DESCRIPTION,
                                .CategoryID = t.CATEGORY_ID,
                                .Price = t.PRICE,
                                .SortNo = t.SORT_NO}).First
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try

            model = obj
        End If

        ViewData("CategoryID") = New SelectList(ctrl, "Value", "Text", model.CategoryID)

        Return View(model)
    End Function

    <HttpPost()>
    Function EditProduct(ByVal id As String, ByVal model As ProductModel, ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If collection.Item("button") = "戻る" Then
            Return RedirectToAction("Product", "Product")
        ElseIf collection.Item("button") = "確認" Then
            ' 追加のバリデーション
            If Util.IncludeSpecialCharacter(Util.NStr(model.ProductName)) Then
                ModelState.AddModelError("ProductName", "商品名に機種依存文字は使えません")
            End If

            If Util.IncludeSpecialCharacter(Util.NStr(model.ProductDescription)) Then
                ModelState.AddModelError("ProductDescription", "商品詳細に機種依存文字は使えません")
            End If

            model.ProductID = id
            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

            If ModelState.IsValid Then


                model.CategoryName = (From t In dc.GetTable(Of Categories)() Where t.CATEGORY_ID = model.CategoryID Select t.CATEGORY_NAME).First

                Session("EditProductData") = model
                Return RedirectToAction("EditProductConfirm", "Product")

            End If

            Dim list = From t In dc.GetTable(Of Categories)() Order By t.SORT_NO Ascending

            Dim ctrl As List(Of SelectListItem) = New List(Of SelectListItem)

            For Each item In list
                ctrl.Add(New SelectListItem() With {.Text = item.CATEGORY_NAME, .Value = item.CATEGORY_ID})
            Next

            ViewData("CategoryID") = New SelectList(ctrl, "Value", "Text", model.CategoryID)

            Return View(model)
      
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function

    Function EditProductConfirm() As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim obj As ProductModel = TryCast(Session("EditProductData"), ProductModel)

        If obj Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Return View(obj)
    End Function

    <HttpPost()>
    Function EditProductConfirm(ByVal collection As FormCollection) As ActionResult
        Dim acc As AccountInfo = TryCast(Session("AccountInfo"), AccountInfo)

        ' ログイン情報がなければエラー
        If acc Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        Dim obj As ProductModel = TryCast(Session("EditProductData"), ProductModel)

        If obj Is Nothing Then
            Return RedirectToAction("Maintenance", "Home")
        End If

        If collection.Item("button") = "戻る" Then
            Session("EditProductData") = Nothing
            Return RedirectToAction("EditProduct/" & obj.ProductID, "Product")
        ElseIf collection.Item("button") = "保存" Then
            Dim connStr As String = Util.GetConnectionString
            Dim dc As WebShoppingDBDataContext = New WebShoppingDBDataContext(connStr)

            ' 商品マスタの更新
            Try
                dc.updateProduct(obj.ProductID, obj.ProductName, obj.ProductDescription, Decimal.Parse(obj.Price), obj.CategoryID, obj.SortNo)
                dc.SubmitChanges()
            Catch ex As Exception
                Return RedirectToAction("Maintenance", "Home")
            End Try
            ' セッションのクリア
            Session("EditProductData") = Nothing

            ' メッセージボックスの表示
            Session("MessageBoxTitle") = "商品更新完了"
            Session("MessageBoxMessage") = "商品の更新が完了しました"
            Return RedirectToAction("MessageBox", "Home")
        Else
            Return RedirectToAction("Maintenance", "Home")
        End If
    End Function
End Class
